@@ -3,8 +3,9 @@ from taurus.external.qt import Qt
 from taurus.qt.qtgui.container import TaurusWidget
 from taurus.qt.qtgui.display import TaurusLabel
 from taurus.qt.qtgui.input import TaurusWheelEdit
+from taurus.qt.qtgui.application import TaurusApplication
 
-app = Qt.QApplication(sys.argv)
+app = TaurusApplication(sys.argv, cmd_line_parser=None)
 
 panel = TaurusWidget()
 layout = Qt.QHBoxLayout()
@@ -18,15 +19,11 @@ layout.addWidget(w1)
 layout.addWidget(w2)
 layout.addWidget(w3)
 layout.addWidget(w4)
-w1.setUseParentModel(True)
-w2.setUseParentModel(True)
-w3.setUseParentModel(True)
-w4.setUseParentModel(True)
 panel.setModel('sys/taurustest/1')
-w1.setModel('/position#label')
-w2.setModel('/position')
-w3.setModel('/position')
-w4.setModel('/position#unit')
+w1.setModel('sys/taurustest/1/position#label')
+w2.setModel('sys/taurustest/1/position#rvalue.magnitude')
+w3.setModel('sys/taurustest/1/position#rvalue.magnitude')
+w4.setModel('sys/taurustest/1/position#unit')
 
 panel.show()
 sys.exit(app.exec_())
