@@ -2,7 +2,7 @@ import sys
 from taurus.external.qt import Qt
 from taurus.qt.qtgui.application import TaurusApplication
 
-app = TaurusApplication(sys.argv)
+app = TaurusApplication(sys.argv, cmd_line_parser=None)
 panel = Qt.QWidget()
 layout = Qt.QHBoxLayout()
 panel.setLayout(layout)
@@ -10,7 +10,7 @@ panel.setLayout(layout)
 from taurus.qt.qtgui.display import TaurusLabel
 w = TaurusLabel()
 layout.addWidget(w)
-w.model = 'sys/tg_test/1/double_scalar'
+w.model = 'sys/tg_test/1/double_scalar#rvalue.magnitude'
 
 panel.show()
 sys.exit(app.exec_())
