@@ -28,7 +28,7 @@ import numpy
 import re
 import weakref
 
-from taurus.external.pint import Quantity
+from taurus.core.units import Quantity
 from taurus.core.taurusattribute import TaurusAttribute
 from taurus.core.taurusbasetypes import SubscriptionState, TaurusEventType, \
     TaurusAttrValue, TaurusTimeVal, AttrQuality, DataType
@@ -60,6 +60,10 @@ class EvaluationAttrValue(TaurusAttrValue):
         self.config = self._attrRef
 
     def __getattr__(self, name):
+        # Do not try to delegate special methods
+        if name.startswith('__') and name.endswith('__'):
+            raise AttributeError("'%s' object has no attribute %s"
+                                 % (self.__class__.__name__, name))   
         try:
             ret = getattr(self._attrRef, name)
         except AttributeError:
@@ -167,17 +171,16 @@ class EvaluationAttribute(TaurusAttribute):
     _factory = None
     _scheme = 'eval'
 
-    def __init__(self, name, parent, **kwargs):
+    def __init__(self, name='', parent=None, **kwargs):
         self.call__init__(TaurusAttribute, name, parent, **kwargs)
         self._value = EvaluationAttrValue(attr=self)
 
-        # Evaluation Attributes are always read-only (at least for now)
         self._label = self.getSimpleName()
-        self.writable = False
         self._references = []
         self._validator = self.getNameValidator()
         self._transformation = None
         self.__subscription_state = SubscriptionState.Unsubscribed
+        self._value_setter = None
 
         # This should never be None because the init already ran the validator
         trstring = self._validator.getExpandedExpr(str(name))
@@ -188,6 +191,35 @@ class EvaluationAttribute(TaurusAttribute):
             self._transformation = trstring
             self.applyTransformation()
 
+        self._initWritable(trstring)
+
+    def _initWritable(self, trstring):
+        # Determine if the device supports writing to this attribute and
+        # initialize the writing infrastructure accordingly
+        self.writable = False
+        try:
+            dev = self.getParentObj()
+            names = trstring.split('.')
+            obj = instance = dev.getSafe()[names[0]]
+            for n in names[1:-1]:
+                obj = getattr(obj, n)
+            obj = getattr(obj.__class__, names[-1])
+        except Exception as e:
+            # self.info("%r", e)
+            return
+        ######################################################################
+        # This check wrongly returns false for writable properties defined with
+        # the @x.setter decorator
+        # TODO: Improve this
+        self.writable = hasattr(obj, 'fset') and obj.fset is not None
+        #######################################################################
+        if self.writable:
+            def value_setter(value):
+                obj.fset(instance, value)
+
+            self._value_setter = value_setter
+            self._value.wvalue = self._value.rvalue
+
     @staticmethod
     def getId(obj, idFormat=r'_V%i_'):
         '''returns an id string for the given object which has the following
@@ -232,7 +264,7 @@ class EvaluationAttribute(TaurusAttribute):
             trstring = v.replaceUnquotedRef(trstring, '{%s}' % r, symbol)
 
         # validate the expression (look for missing symbols)
-        safesymbols = evaluator.getSafe().keys()
+        safesymbols = list(evaluator.getSafe().keys())
         # remove literal text strings from the validation
         trimmedstring = re.sub(QUOTED_TEXT_RE, '', trstring)
         for s in set(re.findall(PY_VAR_RE, trimmedstring)):
@@ -306,7 +338,16 @@ class EvaluationAttribute(TaurusAttribute):
         try:
             evaluator = self.getParentObj()
             rvalue = evaluator.eval(self._transformation)
-            value_dimension = len(numpy.shape(rvalue))
+            # --------------------------------------------------------- 
+            # Workaround for https://github.com/hgrecco/pint/issues/509
+            # The numpy.shape method over a Quantity mutates
+            # the type of its magnitude.
+            # TODO: remove "if" when the bug is solved in pint
+            if hasattr(rvalue, "magnitude"):
+                value_dimension = len(numpy.shape(rvalue.magnitude))
+            else:
+                value_dimension = len(numpy.shape(rvalue))
+            # ---------------------------------------------------------
             value_dformat = DataFormat(value_dimension)
             self.data_format = value_dformat
             self.type = self._encodeType(rvalue, value_dformat)
@@ -322,7 +363,7 @@ class EvaluationAttribute(TaurusAttribute):
             self._value.rvalue = rvalue
             self._value.time = TaurusTimeVal.now()
             self._value.quality = AttrQuality.ATTR_VALID
-        except Exception, e:
+        except Exception as e:
             self._value.quality = AttrQuality.ATTR_INVALID
             msg = " the function '%s' could not be evaluated. Reason: %s" \
                 % (self._transformation, repr(e))
@@ -371,7 +412,15 @@ class EvaluationAttribute(TaurusAttribute):
         return attr_value
 
     def write(self, value, with_read=True):
-        raise TaurusException('Evaluation attributes are read-only')
+        if not self.isWritable():
+            raise TaurusException('Attempt to write on read-only attribute %s',
+                                  self.getFullName())
+        self._value_setter(value)
+        self._value.wvalue = value
+
+        if with_read:
+            ret=self.read(cache=False)
+            return ret
 
     def read(self, cache=True):
         '''returns the value of the attribute.
@@ -382,6 +431,7 @@ class EvaluationAttribute(TaurusAttribute):
 
         :return: attribute value
         '''
+
         if not cache:
             symbols = {}
             for ref in self._references:
@@ -395,12 +445,6 @@ class EvaluationAttribute(TaurusAttribute):
         v = self.read(cache=False)
         self.fireEvent(TaurusEventType.Periodic, v)
 
-    def _subscribeEvents(self):
-        pass
-
-    def _unsubscribeEvents(self):
-        pass
-
     def isUsingEvents(self):
         # if this attributes depends from others, then we consider it uses
         # events
@@ -438,7 +482,8 @@ class EvaluationAttribute(TaurusAttribute):
         if len(self._listeners) > 1 and \
            (initial_subscription_state == SubscriptionState.Subscribed or
                 self.isPollingActive()):
-            Manager().addJob(self.__fireRegisterEvent, None, (listener,))
+            Manager().enqueueJob(self.__fireRegisterEvent,
+                                 job_args=((listener,),))
         return ret
 
     def removeListener(self, listener):
