@@ -26,11 +26,15 @@
 """
 resfactory.py:
 """
+from __future__ import absolute_import
+from future.utils import string_types
 
 import os
 import imp
-import operator
-import types
+try:
+    from collections.abc import Mapping
+except ImportError:  # bck-compat py 2.7
+    from collections import Mapping
 
 from taurus.core.taurushelper import Manager
 from taurus.core.util.singleton import Singleton
@@ -84,13 +88,13 @@ class ResourcesFactory(Singleton, TaurusFactory, Logger):
         """
         if priority < 1:
             raise ValueError('priority must be >=1')
-        if operator.isMappingType(obj):
+        if isinstance(obj, Mapping):
             name = name or 'DICT%02d' % priority
-        elif type(obj) in types.StringTypes or obj is None:
+        elif type(obj) in (str,) or obj is None:
             name, mod = self.__reloadResource(obj)
             obj = {}
             for k, v in mod.__dict__.items():
-                if not k.startswith('_') and isinstance(v, basestring):
+                if not k.startswith('_') and isinstance(v, string_types):
                     obj[k] = v
         else:
             raise TypeError
@@ -105,7 +109,7 @@ class ResourcesFactory(Singleton, TaurusFactory, Logger):
         if pl is None:
             self._resource_priority[priority] = pl = []
         pl.append(name)
-        self._resource_priority_keys = self._resource_priority.keys()
+        self._resource_priority_keys = list(self._resource_priority.keys())
         self._resource_priority_keys.sort()
         return obj
 
@@ -136,7 +140,7 @@ class ResourcesFactory(Singleton, TaurusFactory, Logger):
             m = imp.load_module(module_name, file_, pathname, desc)
             if file_:
                 file_.close()
-        except Exception, e:
+        except Exception as e:
             if file_:
                 file_.close()
             raise e
@@ -246,15 +250,15 @@ class ResourcesFactory(Singleton, TaurusFactory, Logger):
 
     def getAuthorityNameValidator(self):
         """Return ResourceAuthorityNameValidator"""
-        import resvalidator
+        from . import resvalidator
         return resvalidator.ResourceAuthorityNameValidator()
 
     def getDeviceNameValidator(self):
         """Return ResourceDeviceNameValidator"""
-        import resvalidator
+        from . import resvalidator
         return resvalidator.ResourceDeviceNameValidator()
 
     def getAttributeNameValidator(self):
         """Return ResourceAttributeNameValidator"""
-        import resvalidator
+        from . import resvalidator
         return resvalidator.ResourceAttributeNameValidator()
