@@ -103,11 +103,14 @@ Finally, the TangoFactory object can be accessed as::
           issue warnings if detected.
 """
 
-__docformat__ = "restructuredtext"
+from __future__ import absolute_import
 
-from enums import *
-from tangodatabase import *
-from tangodevice import *
-from tangofactory import *
-from tangoattribute import *
-from tangoconfiguration import *
+from .enums import *
+from .tangodatabase import *
+from .tangodevice import *
+from .tangofactory import *
+from .tangoattribute import *
+from .tangoconfiguration import *
+
+
+__docformat__ = "restructuredtext"
