@@ -31,15 +31,16 @@ __docformat__ = 'restructuredtext'
 
 import numpy
 import PyTango
-from taurus.external import unittest
-from taurus.external.pint import Quantity
+import unittest
+from taurus.core.units import Quantity, UR
+from pint import UndefinedUnitError
+
 import taurus
 from taurus.core import DataType, DataFormat
 from taurus.core.tango.tangoattribute import TangoAttrValue
 from taurus.core.tango.test import TangoSchemeTestLauncher
 from taurus.test import insertTest
 from taurus.core.taurusbasetypes import AttrQuality
-from taurus.core.tango.util.tango_taurus import unit_from_tango
 
 _INT_IMG = numpy.arange(2 * 3, dtype='int16').reshape((2, 3))
 _INT_SPE = _INT_IMG[1, :]
@@ -156,90 +157,90 @@ _UINT8_SPE = _UINT8_IMG[1, :]
 # Test encode-decode of strings, booleans and uchars
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_image',
-            setvalue=Quantity(_UINT8_IMG, 'mm'),
-            expected=dict(rvalue=Quantity(_UINT8_IMG, 'mm'),
-                          wvalue=Quantity(_UINT8_IMG, 'mm'),
-                          type=DataType.Integer,
+            setvalue=_UINT8_IMG,
+            expected=dict(rvalue=_UINT8_IMG,
+                          wvalue=_UINT8_IMG,
+                          type=DataType.Bytes,
                           label='uchar_image',
                           writable=True,
                           ),
-            expected_attrv=dict(rvalue=Quantity(_UINT8_IMG, 'mm'),
+            expected_attrv=dict(rvalue=_UINT8_IMG,
                                 value=_UINT8_IMG,
-                                wvalue=Quantity(_UINT8_IMG, 'mm'),
+                                wvalue=_UINT8_IMG,
                                 w_value=_UINT8_IMG,
                                 quality=AttrQuality.ATTR_VALID
                                 )
             )
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_spectrum',
-            setvalue=Quantity(_UINT8_SPE, 'mm'),
-            expected=dict(rvalue=Quantity(_UINT8_SPE, 'mm'),
-                          wvalue=Quantity(_UINT8_SPE, 'mm'),
-                          type=DataType.Integer,
+            setvalue=_UINT8_SPE,
+            expected=dict(rvalue=_UINT8_SPE,
+                          wvalue=_UINT8_SPE,
+                          type=DataType.Bytes,
                           writable=True,
                           ),
-            expected_attrv=dict(rvalue=Quantity(_UINT8_SPE, 'mm'),
+            expected_attrv=dict(rvalue=_UINT8_SPE,
                                 value=_UINT8_SPE,
-                                wvalue=Quantity(_UINT8_SPE, 'mm'),
+                                wvalue=_UINT8_SPE,
                                 w_value=_UINT8_SPE,
                                 quality=AttrQuality.ATTR_VALID
                                 )
             )
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_scalar',
-            setvalue=Quantity(12, 'mm'),
-            expected=dict(rvalue=Quantity(12, 'mm'),
-                          wvalue=Quantity(12, 'mm'),
-                          type=DataType.Integer,
+            setvalue=12,
+            expected=dict(rvalue=12,
+                          wvalue=12,
+                          type=DataType.Bytes,
                           writable=True,
                           range=[None, None],
                           alarms=[None, None],
                           warnings=[None, None]
                           ),
-            expected_attrv=dict(rvalue=Quantity(12, 'mm'),
+            expected_attrv=dict(rvalue=12,
                                 value=12,
-                                wvalue=Quantity(12, 'mm'),
+                                wvalue=12,
                                 w_value=12,
                                 quality=AttrQuality.ATTR_VALID
                                 )
             )
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_image',
-            setvalue=Quantity(_UINT8_IMG, 'mm'),
-            expected=dict(rvalue=Quantity(_UINT8_IMG, 'mm'),
-                          wvalue=Quantity(_UINT8_IMG, 'mm'),
-                          type=DataType.Integer,
+            setvalue=_UINT8_IMG,
+            expected=dict(rvalue=_UINT8_IMG,
+                          wvalue=_UINT8_IMG,
+                          type=DataType.Bytes,
                           label='uchar_image',
                           writable=True,
                           ),
-            expected_attrv=dict(rvalue=Quantity(_UINT8_IMG, 'mm'),
+            expected_attrv=dict(rvalue=_UINT8_IMG,
                                 value=_UINT8_IMG,
-                                wvalue=Quantity(_UINT8_IMG, 'mm'),
+                                wvalue=_UINT8_IMG,
                                 w_value=_UINT8_IMG,
                                 quality=AttrQuality.ATTR_VALID
                                 )
             )
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_spectrum',
-            setvalue=Quantity(_UINT8_SPE, 'mm'),
-            expected=dict(rvalue=Quantity(_UINT8_SPE, 'mm'),
-                          wvalue=Quantity(_UINT8_SPE, 'mm'),
-                          type=DataType.Integer,
+            setvalue=_UINT8_SPE,
+            expected=dict(rvalue=_UINT8_SPE,
+                          wvalue=_UINT8_SPE,
+                          type=DataType.Bytes,
                           writable=True,
                           ),
-            expected_attrv=dict(rvalue=Quantity(_UINT8_SPE, 'mm'),
+            expected_attrv=dict(rvalue=_UINT8_SPE,
                                 value=_UINT8_SPE,
-                                wvalue=Quantity(_UINT8_SPE, 'mm'),
+                                wvalue=_UINT8_SPE,
                                 w_value=_UINT8_SPE,
                                 quality=AttrQuality.ATTR_VALID
                                 )
             )
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_scalar',
-            setvalue=Quantity(12, 'mm'),
-            expected=dict(rvalue=Quantity(12, 'mm'),
-                          wvalue=Quantity(12, 'mm'),
-                          type=DataType.Integer,
+            setvalue=12,
+            expected=dict(rvalue=12,
+                          wvalue=12,
+                          type=DataType.Bytes,
                           writable=True,
                           range=[None, None],
                           alarms=[None, None],
@@ -532,7 +533,7 @@ _UINT8_SPE = _UINT8_IMG[1, :]
             attrname='uchar_image_ro',
             expected=dict(rvalue=Quantity([[1] * 3] * 3, 'mm'),
                           wvalue=None,
-                          type=DataType.Integer
+                          type=DataType.Bytes
                           ),
             expected_attrv=dict(value=[[1] * 3] * 3,
                                 w_value=None,
@@ -543,9 +544,9 @@ _UINT8_SPE = _UINT8_IMG[1, :]
 
 @insertTest(helper_name='write_read_attr',
             attrname='uchar_scalar_ro',
-            expected=dict(rvalue=Quantity(1, 'mm'),
+            expected=dict(rvalue=1,
                           wvalue=None,
-                          type=DataType.Integer,
+                          type=DataType.Bytes,
                           data_format=DataFormat._0D,
                           writable=False,
                           range=[None, None],
@@ -733,7 +734,10 @@ class AttributeTestCase(TangoSchemeTestLauncher, unittest.TestCase):
         """
         dev = PyTango.DeviceProxy(self.DEV_NAME)
         infoex = dev.get_attribute_config_ex(attr_name)[0]
-        unit = unit_from_tango(infoex.unit)
+        try:
+            unit = UR.parse_units(infoex.unit)
+        except (UndefinedUnitError, UnicodeDecodeError):
+            unit = UR.parse_units(None)
         if cfg in ['range', 'alarms', 'warnings']:
             if cfg == 'range':
                 low = infoex.min_value
@@ -797,7 +801,7 @@ class AttributeTestCase(TangoSchemeTestLauncher, unittest.TestCase):
         self.assertTrue(isinstance(read_value, TangoAttrValue), msg)
 
         # Test attribute
-        for k, exp in expected.iteritems():
+        for k, exp in expected.items():
             try:
                 got = getattr(a, k)
             except AttributeError:
@@ -805,11 +809,11 @@ class AttributeTestCase(TangoSchemeTestLauncher, unittest.TestCase):
                        (attrname, k))
                 self.fail(msg)
             msg = ('%s for "%s" should be %r (got %r)' %
-                   (k, attrname,  exp, got))
+                   (k, attrname, exp, got))
             self.__assertValidValue(exp, got, msg)
 
         # Test attribute value
-        for k, exp in expected_attrv.iteritems():
+        for k, exp in expected_attrv.items():
             try:
                 got = getattr(read_value, k)
             except AttributeError:
@@ -832,18 +836,22 @@ class AttributeTestCase(TangoSchemeTestLauncher, unittest.TestCase):
         if isinstance(exp, Quantity):
             exp = exp.magnitude
         try:
-            # for those values that can be handled by numpy.allclose()
-            chk = numpy.allclose(got, exp)
+            # first try the most generic equality
+            chk = bool(got == exp)
         except:
-            if isinstance(got, numpy.ndarray):
-                # uchars were not handled with allclose
-                # UGLY!! but numpy.all does not work
-                chk = got.tolist() == exp.tolist()
-            else:
-                # for the rest
-                chk = bool(got == exp)
-
+            chk = False
+        if not chk:
+            # some cases may fail the simple equality but still be True
+            try:
+                # for those values that can be handled by numpy.allclose()
+                chk = numpy.allclose(got, exp)
+            except:
+                if isinstance(got, numpy.ndarray):
+                    # uchars were not handled with allclose
+                    # UGLY!! but numpy.all does not work
+                    chk = got.tolist() == exp.tolist()
         self.assertTrue(chk, msg)
 
+
 if __name__ == '__main__':
     pass
