@@ -286,12 +286,12 @@ class TaurusAttribute(TaurusModel):
 
     def getDisplayDescrObj(self, cache=True):
         name = self.getLabel(cache=cache)
-        obj = [('name', name),
-               ('model', self.getFullName() or '')]
+        obj = [(u'name', name),
+               (u'model', self.getFullName() or u'')]
         descr = self.description
         if descr:
-            _descr = descr.replace("<", "&lt;").replace(">", "&gt;")
-            obj.append(('description', _descr))
+            _descr = descr.replace(u"<", u"&lt;").replace(u">", u"&gt;")
+            obj.append((u'description', _descr))
 
         if isinstance(self.rvalue, Quantity):
             _unitless = self.rvalue.unitless
@@ -305,7 +305,7 @@ class TaurusAttribute(TaurusModel):
                 else:
                     low = range[0].magnitude
                     high = range[1].magnitude
-                obj.append(('range', "[%s, %s]" % (low, high)))
+                obj.append((u'range', u"[%s, %s]" % (low, high)))
             if alarm != [None, None]:
                 if not _unitless:
                     low = alarm[0]
@@ -313,7 +313,7 @@ class TaurusAttribute(TaurusModel):
                 else:
                     low = alarm[0].magnitude
                     high = alarm[1].magnitude
-                obj.append(('alarm', "[%s, %s]" % (low, high)))
+                obj.append((u'alarm', u"[%s, %s]" % (low, high)))
             if warning != [None, None]:
                 if not _unitless:
                     low = warning[0]
@@ -321,7 +321,7 @@ class TaurusAttribute(TaurusModel):
                 else:
                     low = warning[0].magnitude
                     high = warning[1].magnitude
-                obj.append(('warning', "[%s, %s]" % (low, high)))
+                obj.append((u'warning', u"[%s, %s]" % (low, high)))
         return obj
 
     def isWritable(self, cache=True):
