@@ -1,4 +1,6 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
 #############################################################################
 ##
 # This file is part of Taurus
@@ -35,3 +37,6 @@ from pint import UnitRegistry
 UR = UnitRegistry()
 UR.default_format = '~'  # use abbreviated units
 Q_ = Quantity = UR.Quantity
+
+# Support degreeC
+UR.define(u'degreeC = kelvin; offset: 273.15  = °C = ºC = degC = celsius')
