@@ -23,13 +23,16 @@
 ##
 #############################################################################
 
+from builtins import str
 import sys
+import click
 import os.path
-import optparse
+import subprocess
 
 import taurus
+import taurus.tauruscustomsettings
 from taurus.external.qt import Qt
-
+from taurus.core.util.log import deprecation_decorator
 
 def env_index(env, env_name):
     env_name = str(env_name)
@@ -72,17 +75,24 @@ def append_or_create_env_list(env, env_name, env_value):
 
 
 def get_qtdesigner_bin():
+    designer_bin = getattr(taurus.tauruscustomsettings, 'QT_DESIGNER_PATH', None)
+    if designer_bin:
+        return designer_bin
     designer_bin = str(Qt.QLibraryInfo.location(Qt.QLibraryInfo.BinariesPath))
 
     plat = sys.platform
     if plat == "darwin":
         designer_bin = os.path.join(
-            designer_bin, "Designer.app", "Contents", "MacOS")
+            designer_bin, "Designer.app", "Contents", "MacOS", "designer")
     elif plat in ("win32", "nt"):
-        import PyQt4
-        designer_bin = os.path.abspath(os.path.dirname(PyQt4.__file__))
-
-    designer_bin = os.path.join(designer_bin, "designer")
+        designer_bin = os.path.join(designer_bin, "designer.exe")
+        if not os.path.exists(designer_bin):
+            # some installations don't properly install designer
+            # in QLibraryInfo.BinariesPath. We do a best effort to find it
+            designer_bin = subprocess.check_output('where designer')
+            designer_bin = designer_bin.decode().strip()
+    else:
+        designer_bin = os.path.join(designer_bin, "designer")
     return designer_bin
 
 
@@ -94,8 +104,8 @@ def get_taurus_designer_path():
     return [taurus_qt_designer_path]
 
 
+@deprecation_decorator(alt='get_taurus_designer_env', rel='4.5')
 def qtdesigner_prepare_taurus(env=None, taurus_extra_path=None):
-
     # Tell Qt Designer where it can find the directory containing the plugins
     if env is None:
         env = Qt.QProcess.systemEnvironment()
@@ -115,41 +125,52 @@ def qtdesigner_prepare_taurus(env=None, taurus_extra_path=None):
     return env
 
 
+def get_taurus_designer_env(taurus_extra_path=None):
+
+    env = Qt.QProcessEnvironment.systemEnvironment()
+
+    # Set PYQTDESIGNERPATH to look inside taurus for designer plugins
+    (taurus_designer_path,) = get_taurus_designer_path()
+    env.insert("PYQTDESIGNERPATH", taurus_designer_path)
+
+    # Set TAURUSQTDESIGNERPATH
+    if taurus_extra_path is not None:
+        env.insert("TAURUSQTDESIGNERPATH", taurus_extra_path)
+        env.insert("PYTHONPATH", taurus_extra_path)
+
+    return env
+
+
 def qtdesigner_start(args, env=None):
+
     # Start Designer.
     designer_bin = get_qtdesigner_bin()
 
     designer = Qt.QProcess()
     designer.setProcessChannelMode(Qt.QProcess.ForwardedChannels)
-    designer.setEnvironment(env)
+    if isinstance(env, Qt.QProcessEnvironment):
+        designer.setProcessEnvironment(env)
+    else: # obsolete call, only for bck-compat
+        taurus.deprecated(dep='passing env which is not a QProcessEnvironment',
+                          alt='QProcessEnvironment', rel='4.5')
+        designer.setEnvironment(env)
     designer.start(designer_bin, args)
     designer.waitForFinished(-1)
 
     return designer.exitCode()
 
 
-def main(env=None):
-    version = "taurusdesigner %s" % (taurus.Release.version)
-    usage = "Usage: %prog [options] <ui file(s)>"
-    description = "The Qt designer application customized for taurus"
-    parser = optparse.OptionParser(
-        version=version, usage=usage, description=description)
-    parser.add_option("--taurus-path", dest="tauruspath", default="",
-                      help="additional directories to look for taurus widgets")
-    parser.add_option("--qt-designer-path", dest="pyqtdesignerpath", default="",
-                      help="additional directories to look for python qt widgets")
+@click.command('designer')
+@click.argument('ui_files', nargs=-1)
+@click.option("--taurus-path", "tauruspath",
+              metavar='TAURUSPATH',
+              default=None,
+              help="additional directories to look for taurus widgets")
+def designer_cmd(ui_files, tauruspath):
+    """Launch a Taurus-customized Qt Designer application"""
 
-    options, args = parser.parse_args()
-
-    taurus_extra_path = None
-    # Set TAURUSQTDESIGNERPATH
-    if len(options.tauruspath) > 0:
-        taurus_extra_path = options.tauruspath
-
-    env = qtdesigner_prepare_taurus(
-        env=env, taurus_extra_path=taurus_extra_path)
-
-    sys.exit(qtdesigner_start(args, env=env))
+    env = get_taurus_designer_env(taurus_extra_path=tauruspath)
+    sys.exit(qtdesigner_start(ui_files, env=env))
 
 if __name__ == "__main__":
-    main()
+    designer_cmd()
