@@ -25,14 +25,16 @@
 
 """This module provides basic taurus container widgets"""
 
+from __future__ import absolute_import
+
+from taurus.external.qt import Qt
+from .taurusbasecontainer import TaurusBaseContainer
+
+
 __all__ = ["TaurusFrame"]
 
 __docformat__ = 'restructuredtext'
 
-from taurus.external.qt import Qt
-from taurus.qt.qtgui.base import TaurusBaseComponent
-from taurusbasecontainer import TaurusBaseContainer
-
 
 class TaurusFrame(Qt.QFrame, TaurusBaseContainer):
     """This is a Qt.QFrame that additionally accepts a model property.
@@ -49,8 +51,8 @@ class TaurusFrame(Qt.QFrame, TaurusBaseContainer):
         widget.model = 'sys/database/2'
         stateWidget = TaurusLabel()
         layout.addWidget(stateWidget)
-        stateWidget.useParentModel = True
-        stateWidget.model = '/state'"""
+        stateWidget.model = 'sys/database/2/state'
+        """
 
     modelChanged = Qt.pyqtSignal('const QString &')
 
@@ -113,14 +115,11 @@ def demo():
     frame.setLayout(layout)
     import taurus.qt.qtgui.display
     state_led = taurus.qt.qtgui.display.TaurusLed()
-    state_led.useParentModel = True
-    state_led.model = "/state"
+    state_led.model = frame.model + "/state"
     status_label = taurus.qt.qtgui.display.TaurusLabel()
-    status_label.useParentModel = True
-    status_label.model = "/status"
+    status_label.model = frame.model + "/status"
     double_scalar_label = taurus.qt.qtgui.display.TaurusLabel()
-    double_scalar_label.useParentModel = True
-    double_scalar_label.model = "/double_scalar"
+    double_scalar_label.model = frame.model + "/double_scalar"
     layout.addRow("State:", state_led)
     layout.addRow("Status:", status_label)
     layout.addRow("Double scalar:", double_scalar_label)
