@@ -27,22 +27,32 @@
 mainwindow.py: a main window implementation with many added features by default
 """
 
-__all__ = ["TaurusMainWindow"]
+from __future__ import absolute_import
 
-__docformat__ = 'restructuredtext'
+from builtins import str
 
 import os
 import sys
 
+from functools import partial
+
+from future.utils import string_types
+
 from taurus import tauruscustomsettings
-from taurus.external.qt import Qt
-from taurusbasecontainer import TaurusBaseContainer
+from taurus.core.util import deprecation_decorator
+from taurus.external.qt import Qt, compat
+from .taurusbasecontainer import TaurusBaseContainer
 
 from taurus.qt.qtcore.configuration import BaseConfigurableClass
 from taurus.qt.qtgui.util import ExternalAppAction
 from taurus.qt.qtgui.dialog import protectTaurusMessageBox
 
 
+__all__ = ["TaurusMainWindow"]
+
+__docformat__ = 'restructuredtext'
+
+
 class CommandArgsLineEdit(Qt.QLineEdit):
     ''' An specialized QLineEdit that can transform its text from/to command argument lists'''
 
@@ -52,7 +62,7 @@ class CommandArgsLineEdit(Qt.QLineEdit):
         self.textEdited.connect(self.setCmdText)
 
     def setCmdText(self, cmdargs):
-        if not isinstance(cmdargs, (basestring, Qt.QString)):
+        if not isinstance(cmdargs, string_types):
             cmdargs = " ".join(cmdargs)
         self.setText(cmdargs)
         self._extapp.setCmdArgs(self.getCmdArgs(), False)
@@ -89,7 +99,7 @@ class ConfigurationDialog(Qt.QDialog, BaseConfigurableClass):
             self.externalAppsPage.setWidgetResizable(True)
             self._tabwidget.addTab(self.externalAppsPage,
                                    "External Application Paths")
-        label = "Command line for %s" % unicode(extapp.text())
+        label = "Command line for %s" % str(extapp.text())
         editWidget = CommandArgsLineEdit(extapp, " ".join(extapp.cmdArgs()))
         #editWidget = Qt.QLineEdit(" ".join(extapp.cmdArgs()))
         self.externalAppsPage.widget().layout().addRow(label, editWidget)
@@ -109,8 +119,7 @@ class ConfigurationDialog(Qt.QDialog, BaseConfigurableClass):
             if widget is not None:
                 text = str(widget.text())  # command1
                 if isinstance(widget, Qt.QLabel):
-                    dialog_text = "Command line for %s" % unicode(
-                        extapp.text())
+                    dialog_text = "Command line for %s" % str(extapp.text())
                     if text == dialog_text:
                         layout.removeWidget(widget)
                         widget.close()
@@ -175,36 +184,65 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
 
     '''
     modelChanged = Qt.pyqtSignal('const QString &')
-    perspectiveChanged = Qt.pyqtSignal(str)
+    perspectiveChanged = Qt.pyqtSignal('QString')
 
     # customization options:
-    # blinking semi-period in ms. Set to None for not showing the Heart beat
-    # LED
-    _heartbeat = 1500
-    _showFileMenu = True
-    _showViewMenu = True
-    _showTaurusMenu = True
-    _showToolsMenu = True
-    _showHelpMenu = True
-    # Allows the user to change/create/delete perspectives
-    _supportUserPerspectives = True
-    _showLogger = True
-    _splashLogo = ":/TaurusSplash.png"  # set to None for disabling splash screen
-    _splashMessage = "Initializing Main window..."
+    #: Heartbeat LED blinking semi-period in ms. Set to None for not showing it
+    HEARTBEAT = 1500
+    #: Whether to show the File menu
+    FILE_MENU_ENABLED = True
+    #: Whether to show the View menu
+    VIEW_MENU_ENABLED = True
+    #: Whether to show the Taurus menu
+    TAURUS_MENU_ENABLED = True
+    #: Whether to show the Tools menu
+    TOOLS_MENU_ENABLED = True
+    #: Whether to show the Help menu
+    HELP_MENU_ENABLED = True
+    #: Whether to show the Full Screen Toolbar
+    FULLSCREEN_TOOLBAR_ENABLED = True
+    #: Whether to show actions for user perspectives
+    USER_PERSPECTIVES_ENABLED = True
+    #: Whether add a dockwidget with the logger widget
+    LOGGER_WIDGET_ENABLED = True
+    #: Name of logo image for splash screen. Set to None for disabling splash
+    SPLASH_LOGO_NAME = "large:TaurusSplash.png"
+    #: Message for splash screen
+    SPLASH_MESSAGE = "Initializing Main window..."
+
+    _old_options_api = {
+        '_heartbeat': 'HEARTBEAT',
+        '_showFileMenu': 'FILE_MENU_ENABLED',
+        '_showViewMenu': 'VIEW_MENU_ENABLED',
+        '_showTaurusMenu': 'TAURUS_MENU_ENABLED',
+        '_showToolsMenu': 'TOOLS_MENU_ENABLED',
+        '_showHelpMenu': 'HELP_MENU_ENABLED',
+        '_showLogger': 'LOGGER_WIDGET_ENABLED',
+        '_supportUserPerspectives': 'USER_PERSPECTIVES_ENABLED',
+        '_splashLogo': 'SPLASH_LOGO_NAME',
+        '_splashMessage': 'SPLASH_MESSAGE',
+    }
 
     def __init__(self, parent=None, designMode=False, splash=None):
         name = self.__class__.__name__
         self.call__init__wo_kw(Qt.QMainWindow, parent)
         self.call__init__(TaurusBaseContainer, name, designMode=designMode)
+
+        # Provide bck-compat with old options API
+        for old, new in self._old_options_api.items():
+            if hasattr(self, old):
+                self.deprecated(dep=old, alt=new, rel='4.5.3a')
+                setattr(self, new, getattr(self, old))
+
         if splash is None:
-            splash = bool(self._splashLogo)
+            splash = bool(self.SPLASH_LOGO_NAME)
 
         self.__splashScreen = None
         if splash and not designMode:
             self.__splashScreen = Qt.QSplashScreen(
-                Qt.QPixmap(self._splashLogo))
+                Qt.QPixmap(self.SPLASH_LOGO_NAME))
             self.__splashScreen.show()
-            self.__splashScreen.showMessage(self._splashMessage)
+            self.__splashScreen.showMessage(self.SPLASH_MESSAGE)
 
         self.__tangoHost = ""
         self.__settings = None
@@ -213,10 +251,12 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
 
         self.helpManualDW = None
         self.helpManualBrowser = None
-        self.resetHelpManualURI()
+
+        if self.HELP_MENU_ENABLED:
+            self.resetHelpManualURI()
 
         # Heartbeat
-        if self._heartbeat is not None:
+        if self.HEARTBEAT is not None:
             from taurus.qt.qtgui.display import QLed
             self.heartbeatLed = QLed()
             self.heartbeatLed.setToolTip(
@@ -233,34 +273,49 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         self.__createActions()
 
         # logger dock widget
-        if self._showLogger:
+        if self.LOGGER_WIDGET_ENABLED:
             self.addLoggerWidget()
 
         # Create Menus
-        if self._showFileMenu:  # File menu
+        if self.FILE_MENU_ENABLED:  # File menu
             self.createFileMenu()
-        if self._showViewMenu:  # View menu
+        if self.VIEW_MENU_ENABLED:  # View menu
             self.createViewMenu()
-        if self._showTaurusMenu:  # Taurus Menu
+        if self.TAURUS_MENU_ENABLED:  # Taurus Menu
             self.createTaurusMenu()
-        if self._showToolsMenu:  # Tools Menu
+        if self.TOOLS_MENU_ENABLED:  # Tools Menu
             self.createToolsMenu()
-        if self._showHelpMenu:  # Help Menu
+        if self.HELP_MENU_ENABLED:  # Help Menu
             self.createHelpMenu()
 
         # View Toolbar
-        self.viewToolBar = self.addToolBar("View")
-        self.viewToolBar.setObjectName("viewToolBar")
-        self.viewToolBar.addAction(self.toggleFullScreenAction)
+        if self.FULLSCREEN_TOOLBAR_ENABLED:
+            self.viewToolBar = self.addToolBar("View")
+            self.viewToolBar.setObjectName("viewToolBar")
+            self.viewToolBar.addAction(self.toggleFullScreenAction)
 
         # Perspectives Toolbar
-        if self._supportUserPerspectives:
+        if self.USER_PERSPECTIVES_ENABLED:
             self.createPerspectivesToolBar()
 
         # disable the configuration action if there is nothing to configure
         self.configurationAction.setEnabled(
             self.configurationDialog._tabwidget.count())
 
+    def __setattr__(self, key, value):
+        super(TaurusMainWindow, self).__setattr__(key, value)
+        if key in self._old_options_api:
+            new = self._old_options_api[key]
+            setattr(self, new, value)
+            self.deprecated(dep=key, alt=new, rel='4.5.3a')
+
+    def contextMenuEvent(self, event):
+        """Reimplemented to avoid deprecation warning related to:
+        https://github.com/taurus-org/taurus/issues/905
+        """
+        # TODO: Remove this once the deprecation of the Popup menu is enforced
+        event.ignore()
+
     def addLoggerWidget(self, hidden=True):
         '''adds a QLoggingWidget as a dockwidget of the main window (and hides it by default)'''
         from taurus.qt.qtgui.table import QLoggingWidget
@@ -275,7 +330,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
     def createFileMenu(self):
         '''adds a "File" Menu'''
         self.fileMenu = self.menuBar().addMenu("File")
-        if self._supportUserPerspectives:
+        if self.USER_PERSPECTIVES_ENABLED:
             self.fileMenu.addAction(self.importSettingsFileAction)
             self.fileMenu.addAction(self.exportSettingsFileAction)
             # self.fileMenu.addAction(self.resetSettingsAction)
@@ -285,12 +340,12 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
     def createViewMenu(self):
         '''adds a "View" Menu'''
         self.viewMenu = self.menuBar().addMenu("View")
-        if self._showLogger:
+        if self.LOGGER_WIDGET_ENABLED:
             self.viewMenu.addAction(self.__loggerDW.toggleViewAction())
         self.viewToolBarsMenu = self.viewMenu.addMenu("Tool Bars")
         self.viewMenu.addSeparator()
         self.viewMenu.addAction(self.toggleFullScreenAction)
-        if self._supportUserPerspectives:
+        if self.USER_PERSPECTIVES_ENABLED:
             self.viewMenu.addSeparator()
             self.perspectivesMenu = Qt.QMenu("Load Perspectives", self)
             self.viewMenu.addMenu(self.perspectivesMenu)
@@ -330,7 +385,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         pbutton.setMenu(self.perspectivesMenu)
         self.perspectivesToolBar.addWidget(pbutton)
         self.perspectivesToolBar.addAction(self.savePerspectiveAction)
-        if self._showViewMenu:
+        if self.VIEW_MENU_ENABLED:
             self.viewToolBarsMenu.addAction(
                 self.perspectivesToolBar.toggleViewAction())
 
@@ -340,19 +395,30 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         .. note:: This method may need be called by derived classes at the end
                   of their initialization.
 
-        :return: (QMenu) the updated perspectives menu (or None if self._supportUserPerspectives is False)
+        :return: (QMenu) the updated perspectives menu (or None if
+                 self.USER_PERSPECTIVES_ENABLED is False)
         '''
-        if not self._supportUserPerspectives:
+        if not self.USER_PERSPECTIVES_ENABLED:
             return None
         self.perspectivesMenu.clear()
         for pname in self.getPerspectivesList():
-            self.perspectivesMenu.addAction(
+            a = self.perspectivesMenu.addAction(
                 pname, self.__onPerspectiveSelected)
+            # -------------------------------------------------------
+            # Work around for https://bugs.kde.org/show_bug.cgi?id=345023
+            # TODO: make better solution for this
+            a.perspective_name = pname  # <-- ugly monkey-patch!
+            # -------------------------------------------------------
         return self.perspectivesMenu
 
     def __onPerspectiveSelected(self):
         '''slot to be called by the actions in the perspectivesMenu'''
-        pname = self.sender().text()
+        # -------------------------------------------------------
+        # Work around for https://bugs.kde.org/show_bug.cgi?id=345023
+        # TODO: make better solution for this
+        # pname = self.sender().text()  # <-- this fails because of added "&"
+        pname = self.sender().perspective_name  # <-- this was monkey-patched
+        # -------------------------------------------------------
         self.loadPerspective(name=pname)
 
     def splashScreen(self):
@@ -381,38 +447,45 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         '''initializes the application-wide actions'''
         self.quitApplicationAction = Qt.QAction(
             Qt.QIcon.fromTheme("process-stop"), 'Exit Application', self)
-        self.quitApplicationAction.triggered[()].connect(self.close)
+        self.quitApplicationAction.triggered.connect(self.close)
         self.changeTangoHostAction = Qt.QAction(Qt.QIcon.fromTheme(
             "network-server"), 'Change Tango Host ...', self)
-        self.changeTangoHostAction.setShortcut(Qt.QKeySequence("Ctrl+P"))
-        self.changeTangoHostAction.triggered[()].connect(self._onChangeTangoHostAction)
+        self.changeTangoHostAction.triggered.connect(self._onChangeTangoHostAction)
+        # make this action invisible since it is deprecated
+        self.changeTangoHostAction.setVisible(False)
 
         self.loadPerspectiveAction = Qt.QAction(Qt.QIcon.fromTheme(
             "document-open"), 'Load Perspective ...', self)
-        self.loadPerspectiveAction.triggered[()].connect(self.loadPerspective)
+        self.loadPerspectiveAction.triggered.connect(
+            partial(self.loadPerspective, name=None, settings=None))
 
         self.savePerspectiveAction = Qt.QAction(Qt.QIcon.fromTheme(
             "document-save"), 'Save Perspective ...', self)
-        self.savePerspectiveAction.triggered[()].connect(self.savePerspective)
+        self.savePerspectiveAction.triggered.connect(
+            partial(self.savePerspective, name=None))
 
         self.deletePerspectiveAction = Qt.QAction(
             Qt.QIcon("actions:edit-delete.svg"), 'Delete Perspective ...', self)
-        self.deletePerspectiveAction.triggered[()].connect(self.removePerspective)
+        self.deletePerspectiveAction.triggered.connect(
+            partial(self.removePerspective, name=None, settings=None))
 
         self.exportSettingsFileAction = Qt.QAction(
             Qt.QIcon.fromTheme("document-save"), 'Export Settings ...', self)
-        self.exportSettingsFileAction.triggered[()].connect(self.exportSettingsFile)
+        self.exportSettingsFileAction.triggered.connect(
+            partial(self.exportSettingsFile, fname=None))
 
         self.importSettingsFileAction = Qt.QAction(
             Qt.QIcon.fromTheme("document-open"), 'Import Settings ...', self)
-        self.importSettingsFileAction.triggered[()].connect(self.importSettingsFile)
+        self.importSettingsFileAction.triggered.connect(
+            partial(self.importSettingsFile, fname=None))
 
         #self.resetSettingsAction = Qt.QAction(Qt.QIcon.fromTheme("edit-undo"),'Reset Settings', self)
         #self.connect(self.resetSettingsAction, Qt.SIGNAL("triggered()"), self.resetSettings)
 
         self.configurationAction = Qt.QAction(Qt.QIcon.fromTheme(
             "preferences-system"), 'Configurations ...', self)
-        self.configurationAction.triggered[()].connect(self.configurationDialog.show)
+        self.configurationAction.triggered.connect(
+            self.configurationDialog.show)
 
         #self.rpdb2Action = Qt.QAction("Spawn rpdb2", self)
         self.spawnRpdb2Shortcut = Qt.QShortcut(self)
@@ -606,25 +679,21 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         if group is not None:
             settings.beginGroup(group)
         if not ignoreGeometry:
-            # With API2, from_qvariant is returning None instead
-            ba = Qt.from_qvariant(settings.value(
-                "MainWindow/Geometry"), 'toByteArray') or Qt.QByteArray()
-            # of an empty QByTeArray
-            # and this caused an exception later on. Hence the "or"
+            ba = settings.value("MainWindow/Geometry") or Qt.QByteArray()
             self.restoreGeometry(ba)
         # restore the Taurus config
         try:
-            ba = Qt.from_qvariant(settings.value(
-                "TaurusConfig"), 'toByteArray') or Qt.QByteArray()
+            ba = settings.value("TaurusConfig") or Qt.QByteArray()
             self.applyQConfig(ba)
-        except Exception, e:
-            msg = 'Problem loading configuration from "%s". Some settings may not be restored.\n Details: %s' % (
-                unicode(settings.fileName()), repr(e))
+        except Exception as e:
+            msg = ('Problem loading configuration from "{}". '
+                   + 'Some settings may not be restored.\n'
+                   + ' Reason: {}'
+                   ).format(str(settings.fileName()), e)
             self.error(msg)
             Qt.QMessageBox.warning(
                 self, 'Error Loading settings', msg, Qt.QMessageBox.Ok)
-        ba = Qt.from_qvariant(settings.value(
-            "MainWindow/State"), 'toByteArray') or Qt.QByteArray()
+        ba = settings.value("MainWindow/State") or Qt.QByteArray()
         self.restoreState(ba)
         # hide all dockwidgets (so that they are shown only if they were
         # present in the settings)
@@ -633,8 +702,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         for d in dockwidgets:
             r = self.restoreDockWidget(d)
             d.hide()
-        ba = Qt.from_qvariant(settings.value(
-            "MainWindow/State"), 'toByteArray') or Qt.QByteArray()
+        ba = settings.value("MainWindow/State") or Qt.QByteArray()
         self.restoreState(ba)
 
         if group is not None:
@@ -652,19 +720,24 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
                        saved (no prefix by default)
         '''
         settings = self.getQSettings()
+        if not settings.isWritable():
+            self.info('Settings cannot be saved in "%s"', settings.fileName())
+            return
+
         if group is not None:
             settings.beginGroup(group)
         # main window geometry
-        settings.setValue("MainWindow/State", Qt.QVariant(self.saveState()))
-        settings.setValue("MainWindow/Geometry",
-                          Qt.QVariant(self.saveGeometry()))
+        settings.setValue("MainWindow/State", self.saveState())
+        settings.setValue("MainWindow/Geometry", self.saveGeometry())
 
         # store the config dict
-        settings.setValue("TaurusConfig", Qt.QVariant(self.createQConfig()))
+        settings.setValue("TaurusConfig", self.createQConfig())
         if group is not None:
             settings.endGroup()
-        self.info('MainWindow settings saved in "%s"' % settings.fileName())
+        self.info('Settings saved in "%s"' % settings.fileName())
 
+    @Qt.pyqtSlot()
+    @Qt.pyqtSlot('QString')
     def savePerspective(self, name=None):
         '''Stores current state of the application as a perspective with the given name
 
@@ -672,18 +745,26 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         '''
         perspectives = self.getPerspectivesList()
         if name is None:
-            name, ok = Qt.QInputDialog.getItem(self, "Save Perspective", "Store current settings as the following perspective:",
-                                               perspectives, 0, True)
+            name, ok = Qt.QInputDialog.getItem(
+                self, "Save Perspective",
+                "Store current settings as the following perspective:",
+                perspectives, 0, True
+            )
             if not ok:
                 return
         if name in perspectives:
-            ans = Qt.QMessageBox.question(self, "Overwrite perspective?", "overwrite existing perspective %s?" % unicode(name),
-                                          Qt.QMessageBox.Yes, Qt.QMessageBox.No)
+            ans = Qt.QMessageBox.question(
+                self, "Overwrite perspective?",
+                "overwrite existing perspective %s?" % str(name),
+                Qt.QMessageBox.Yes, Qt.QMessageBox.No
+            )
             if ans != Qt.QMessageBox.Yes:
                 return
         self.saveSettings(group="Perspectives/%s" % name)
         self.updatePerspectivesMenu()
 
+    @Qt.pyqtSlot()
+    @Qt.pyqtSlot('QString')
     def loadPerspective(self, name=None, settings=None):
         '''Loads the settings saved for the given perspective.
         It emits a 'perspectiveChanged' signal with name as its parameter
@@ -722,6 +803,8 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         settings.endGroup()
         return names
 
+    @Qt.pyqtSlot()
+    @Qt.pyqtSlot('QString')
     def removePerspective(self, name=None, settings=None):
         '''removes the given perspective from the settings
 
@@ -749,24 +832,30 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         settings.endGroup()
         self.updatePerspectivesMenu()
 
+    @Qt.pyqtSlot()
+    @Qt.pyqtSlot('QString')
     def exportSettingsFile(self, fname=None):
         '''copies the current settings file into the given file name.
 
         :param fname: (str) name of output file. If None given, a file dialog will be shown.
         '''
         if fname is None:
-            fname = unicode(Qt.QFileDialog.getSaveFileName(self, 'Choose file where the current settings should be saved',
-                                                           '', "Ini files (*.ini);;All files (*)"))
+            fname, _ = compat.getSaveFileName(
+                self, 'Choose file where the current settings should be saved',
+                '', "Ini files (*.ini);;All files (*)"
+            )
             if not fname:
                 return
         self.saveSettings()
         ok = Qt.QFile.copy(self.getQSettings().fileName(), fname)
         if ok:
-            self.info('MainWindow settings saved in "%s"' % unicode(fname))
+            self.info('MainWindow settings saved in "%s"' % str(fname))
         else:
-            msg = 'Settings could not be exported to %s' % unicode(fname)
+            msg = 'Settings could not be exported to %s' % str(fname)
             Qt.QMessageBox.warning(self, 'Export error', msg)
 
+    @Qt.pyqtSlot()
+    @Qt.pyqtSlot('QString')
     def importSettingsFile(self, fname=None):
         '''
         loads settings (including importing all perspectives) from a given ini
@@ -775,8 +864,10 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         :param fname: (str) name of ini file. If None given, a file dialog will be shown.
         '''
         if fname is None:
-            fname = unicode(Qt.QFileDialog.getOpenFileName(self, 'Select a ini-format settings file',
-                                                           '', "Ini files (*.ini);;All files (*)"))
+            fname, _ = compat.getOpenFileName(
+                self, 'Select a ini-format settings file',
+                '', "Ini files (*.ini);;All files (*)"
+            )
             if not fname:
                 return
         s = Qt.QSettings(fname, Qt.QSettings.IniFormat)
@@ -838,12 +929,12 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
                 self.extAppsBar.setObjectName("External Applications")
                 self.extAppsBar.setToolButtonStyle(
                     Qt.Qt.ToolButtonTextBesideIcon)
-                if self._showViewMenu:
+                if self.VIEW_MENU_ENABLED:
                     self.viewToolBarsMenu.addAction(
                         self.extAppsBar.toggleViewAction())
             self.extAppsBar.addAction(extapp)
 
-        if toMenu and self._showToolsMenu:
+        if toMenu and self.TOOLS_MENU_ENABLED:
             if self.toolsMenu is None:
                 self.createToolsMenu()
             self.externalAppsMenu.addAction(extapp)
@@ -875,6 +966,8 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         self.unregisterConfigurableItem("_extApp[%s]" % str(action.text()),
                                         raiseOnError=False)
 
+    @deprecation_decorator(dbg_msg="Change Tango Host action is TangoCentric",
+                           rel="4.1.2")
     def _onChangeTangoHostAction(self):
         '''
         slot called when the Change Tango Host is triggered. It prompts for a
@@ -929,8 +1022,8 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         self.setHelpManualURI(uri)
 
     def showHelpAbout(self):
-        appname = unicode(Qt.qApp.applicationName())
-        appversion = unicode(Qt.qApp.applicationVersion())
+        appname = str(Qt.qApp.applicationName())
+        appversion = str(Qt.qApp.applicationVersion())
         from taurus.core import release
         abouttext = "%s %s\n\nUsing %s %s" % (
             appname, appversion, release.name, release.version)
@@ -955,7 +1048,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
         if key is None:
             from taurus.core.util.user import getSystemUserName
             username = getSystemUserName()
-            appname = unicode(Qt.QApplication.applicationName())
+            appname = str(Qt.QApplication.applicationName())
             key = "__socket_%s-%s__" % (username, appname)
         from taurus.external.qt import QtNetwork
         socket = QtNetwork.QLocalSocket(self)
@@ -1017,7 +1110,7 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
 
     def resetHeartbeat(self):
         '''resets the heartbeat interval'''
-        self.setHeartbeat(self.__class__._heartbeat)
+        self.setHeartbeat(self.__class__.HEARTBEAT)
 
     #-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
     # Public slots for apply/restore changes
@@ -1064,23 +1157,24 @@ class TaurusMainWindow(Qt.QMainWindow, TaurusBaseContainer):
 
 if __name__ == "__main__":
 
-    import taurus.qt.qtgui.application
-    app = taurus.qt.qtgui.application.TaurusApplication()
+    from taurus.qt.qtgui.application import TaurusApplication
+    app = TaurusApplication(cmd_line_parser=None)
     app.setApplicationName('TaurusMainWindow-test')
     app.setOrganizationName('ALBA')
     app.basicConfig()
 
     class MyMainWindow(TaurusMainWindow):
-        _heartbeat = 300  # blinking semi-period in ms. Set to None for not showing the Heart beat LED
-        _showFileMenu = True
-        _showViewMenu = True
-        _showTaurusMenu = False
-        _showToolsMenu = True
-        _showHelpMenu = True
+        HEARTBEAT = 300  # blinking semi-period in ms. Set to None for not showing the Heart beat LED
+        FILE_MENU_ENABLED = True
+        VIEW_MENU_ENABLED = True
+        TAURUS_MENU_ENABLED = False
+        TOOLS_MENU_ENABLED = True
+        HELP_MENU_ENABLED = True
         # Allows the user to change/create/delete perspectives
-        _supportUserPerspectives = True
-        _showLogger = True
-        _splashLogo = ":/TaurusSplash.png"  # set to None for disabling splash screen
+        USER_PERSPECTIVES_ENABLED = True
+        LOGGER_WIDGET_ENABLED = True
+        # set to None for disabling splash screen
+        SPLASH_LOGO_NAME = "large:TaurusSplash.png"
         _splashMessage = "Initializing Main window..."
 
         def __init__(self):
