@@ -39,7 +39,10 @@ import re
 import os
 import subprocess
 import traceback
-import collections
+try:
+    from collections.abc import Sequence
+except ImportError:  # bck-compat py 2.7
+    from collections import Sequence
 
 from future.utils import string_types
 from queue import Queue
@@ -153,7 +156,7 @@ class TaurusGraphicsUpdateThread(Qt.QThread):
                     break
                 else:
                     continue
-            if not isinstance(item, collections.Sequence):
+            if not isinstance(item, Sequence):
                 item = (item,)
             # @todo: Unless the call to boundingRect() has a side effect, this line is useless..  probably related to todo in _updateView()
             item_rects = [i.boundingRect() for i in item]
@@ -365,7 +368,7 @@ class TaurusGraphicsScene(Qt.QGraphicsScene):
 
         strict = (
             not self.ANY_ATTRIBUTE_SELECTS_DEVICE) if strict is None else strict
-        alnum = '(?:[a-zA-Z0-9-_\*]|(?:\.\*))(?:[a-zA-Z0-9-_\*]|(?:\.\*))*'
+        alnum = r'(?:[a-zA-Z0-9-_\*]|(?:\.\*))(?:[a-zA-Z0-9-_\*]|(?:\.\*))*'
         target = str(item_name).strip().split()[0].lower().replace(
             '/state', '')  # If it has spaces only the first word is used
         # Device names should match also its attributes or only state?
@@ -1208,10 +1211,10 @@ class TaurusGraphicsStateItem(TaurusGraphicsItem):
                 bg_brush, fg_brush = None, None
                 if self.getModelObj().getType() == DataType.DevState:
                     bg_brush, fg_brush = QT_DEVICE_STATE_PALETTE.qbrush(
-                        v.value)
+                        v.rvalue)
                 elif self.getModelObj().getType() == DataType.Boolean:
                     bg_brush, fg_brush = QT_DEVICE_STATE_PALETTE.qbrush(
-                        (DevState.FAULT, DevState.ON)[v.value])
+                        (DevState.FAULT, DevState.ON)[v.rvalue])
                 elif self.getShowQuality():
                     bg_brush, fg_brush = QT_ATTRIBUTE_QUALITY_PALETTE.qbrush(
                         v.quality)
@@ -1250,7 +1253,9 @@ class TaurusEllipseStateItem(Qt.QGraphicsEllipseItem, TaurusGraphicsStateItem):
 
     def __init__(self, name=None, parent=None, scene=None):
         name = name or self.__class__.__name__
-        Qt.QGraphicsEllipseItem.__init__(self, parent, scene)
+        Qt.QGraphicsEllipseItem.__init__(self, parent)
+        if scene is not None:
+            scene.addItem(self)
         self.call__init__(TaurusGraphicsStateItem, name, parent)
 
     def paint(self, painter, option, widget=None):
@@ -1264,7 +1269,9 @@ class TaurusRectStateItem(Qt.QGraphicsRectItem, TaurusGraphicsStateItem):
 
     def __init__(self, name=None, parent=None, scene=None):
         name = name or self.__class__.__name__
-        Qt.QGraphicsRectItem.__init__(self, parent, scene)
+        Qt.QGraphicsRectItem.__init__(self, parent)
+        if scene is not None:
+            scene.addItem(self)
         self.call__init__(TaurusGraphicsStateItem, name, parent)
 
     def paint(self, painter, option, widget):
@@ -1278,7 +1285,9 @@ class TaurusSplineStateItem(QSpline, TaurusGraphicsStateItem):
 
     def __init__(self, name=None, parent=None, scene=None):
         name = name or self.__class__.__name__
-        QSpline.__init__(self, parent, scene)
+        QSpline.__init__(self, parent)
+        if scene is not None:
+            scene.addItem(self)
         self.call__init__(TaurusGraphicsStateItem, name, parent)
 
     def paint(self, painter, option, widget):
@@ -1341,7 +1350,9 @@ class TaurusRoundRectStateItem(TaurusRoundRectItem, TaurusGraphicsStateItem):
 class TaurusGroupItem(Qt.QGraphicsItemGroup):
 
     def __init__(self, name=None, parent=None, scene=None):
-        Qt.QGraphicsItemGroup.__init__(self, parent, scene)
+        Qt.QGraphicsItemGroup.__init__(self, parent)
+        if scene is not None:
+            scene.addItem(self)
 
 
 class TaurusGroupStateItem(TaurusGroupItem, TaurusGraphicsStateItem):
@@ -1359,8 +1370,10 @@ class TaurusPolygonStateItem(Qt.QGraphicsPolygonItem, TaurusGraphicsStateItem):
 
     def __init__(self, name=None, parent=None, scene=None):
         name = name or self.__class__.__name__
-        #Qt.QGraphicsRectItem.__init__(self, parent, scene)
-        Qt.QGraphicsPolygonItem.__init__(self, parent, scene)
+        #Qt.QGraphicsRectItem.__init__(self, parent)
+        Qt.QGraphicsPolygonItem.__init__(self, parent)
+        if scene is not None:
+            scene.addItem(self)
         self.call__init__(TaurusGraphicsStateItem, name, parent)
 
     def paint(self, painter, option, widget):
@@ -1374,7 +1387,9 @@ class TaurusLineStateItem(Qt.QGraphicsLineItem, TaurusGraphicsStateItem):
 
     def __init__(self, name=None, parent=None, scene=None):
         name = name or self.__class__.__name__
-        Qt.QGraphicsLineItem.__init__(self, parent, scene)
+        Qt.QGraphicsLineItem.__init__(self, parent)
+        if scene is not None:
+            scene.addItem(self)
         self.call__init__(TaurusGraphicsStateItem, name, parent)
 
     def paint(self, painter, option, widget):
