@@ -32,7 +32,7 @@ __all__ = ["QBaseModelWidget", "TaurusBaseModelWidget",
 
 __docformat__ = 'restructuredtext'
 
-from taurus.external.qt import Qt
+from taurus.external.qt import Qt, compat
 
 from taurus.qt.qtgui.util import ActionFactory
 from taurus.qt.qtgui.base import TaurusBaseWidget
@@ -221,7 +221,7 @@ class RefreshToolBar(BaseToolBar):
 
 class PerspectiveToolBar(BaseToolBar):
 
-    perspectiveChanged = Qt.pyqtSignal(str)
+    perspectiveChanged = Qt.pyqtSignal(compat.PY_OBJECT)
 
     def __init__(self, perspective, view=None, parent=None, designMode=False):
         BaseToolBar.__init__(self, name="Taurus refresh toolbar", view=view,
@@ -275,10 +275,10 @@ class QBaseModelWidget(Qt.QMainWindow):
     KnownPerspectives = {}
     DftPerspective = None
 
-    itemClicked = Qt.pyqtSignal(object, int)
-    itemDoubleClicked = Qt.pyqtSignal(object, int)
+    itemClicked = Qt.pyqtSignal(compat.PY_OBJECT, int)
+    itemDoubleClicked = Qt.pyqtSignal(compat.PY_OBJECT, int)
     itemSelectionChanged = Qt.pyqtSignal()
-    currentItemChanged = Qt.pyqtSignal(object, object)
+    currentItemChanged = Qt.pyqtSignal(compat.PY_OBJECT, compat.PY_OBJECT)
 
     def __init__(self, parent=None, designMode=False, with_filter_widget=True,
                  with_selection_widget=True, with_refresh_widget=True,
@@ -528,7 +528,7 @@ class QBaseModelWidget(Qt.QMainWindow):
         # reversed
         qmodel_class, qmodel_proxy_classes = qmodel_classes[
             -1], qmodel_classes[-2::-1]
-        qmodel = qmodel_class(self)
+        qmodel = qmodel_class(parent=self)
         qmodel_source = qmodel
         if self._proxyModel is None:  # applies the chain of proxies
             for qmodel_proxy_class in qmodel_proxy_classes:
@@ -588,9 +588,6 @@ class TaurusBaseModelWidget(TaurusBaseWidget):
     #: with which this widget will get its data from. The convention used for
     #: the string can be found :ref:`here <model-concept>`.
     #:
-    #: In case the property :attr:`useParentModel` is set to True, the model
-    #: text must start with a '/' followed by the attribute name.
-    #:
     #: **Access functions:**
     #:
     #:     * :meth:`TaurusBaseWidget.getModel`
