@@ -83,7 +83,9 @@ class QRawDataWidget(Qt.QWidget):
 
 if __name__ == "__main__":
     import sys
-    app = Qt.QApplication(sys.argv)
+    from taurus.qt.qtgui.application import TaurusApplication
+
+    app = TaurusApplication(sys.argv, cmd_line_parser=None)
     form = QRawDataWidget()
     form.show()
     sys.exit(app.exec_())
