@@ -26,19 +26,26 @@
 """
 itemsmodel Model and view for new CurveItem configuration
 """
-__all__ = ['TaurusModelModel', 'TaurusModelItem', 'TaurusModelList']
+from builtins import object
+from builtins import bytes
 #raise UnimplementedError('Under Construction!')
 
 import copy
 
+from future.utils import string_types
+
 from taurus.external.qt import Qt
 import taurus
 from taurus.core.taurushelper import getSchemeFromName
 from taurus.core.taurusbasetypes import TaurusElementType
 from taurus.core.taurusexception import TaurusException
-from taurus.qt.qtcore.mimetypes import TAURUS_MODEL_LIST_MIME_TYPE, TAURUS_ATTR_MIME_TYPE, TAURUS_MODEL_MIME_TYPE
+from taurus.qt.qtcore.mimetypes import TAURUS_MODEL_LIST_MIME_TYPE
+from taurus.qt.qtcore.mimetypes import TAURUS_ATTR_MIME_TYPE
+from taurus.qt.qtcore.mimetypes import TAURUS_MODEL_MIME_TYPE
 from taurus.qt.qtgui.icon import getElementTypeIcon
-from taurus.qt.qtcore.util.signal import baseSignal
+
+
+__all__ = ['TaurusModelModel', 'TaurusModelItem', 'TaurusModelList']
 
 # set some named constants
 SRC_ROLE = Qt.Qt.UserRole + 1
@@ -56,6 +63,16 @@ class TaurusModelItem(object):
         if display is not None:
             self.display = display
 
+    def __deepcopy__(self, memo):
+        cls = self.__class__
+        result = cls.__new__(cls)
+        memo[id(self)] = result
+        result.icon = Qt.QIcon(self.icon)
+        result.ok = copy.deepcopy(self.ok, memo)
+        result._src = copy.deepcopy(self._src, memo)
+        result.display = copy.deepcopy(self.display, memo)
+        return result
+
     def __repr__(self):
         ret = "TaurusModelItem('%s')" % (self.display)
         return ret
@@ -142,24 +159,24 @@ class TaurusModelModel(Qt.QAbstractListModel):
     def data(self, index, role=Qt.Qt.DisplayRole):
         '''reimplemented from :class:`Qt.QAbstractListModel`'''
         if not index.isValid() or not (0 <= index.row() < self.rowCount()):
-            return Qt.QVariant()
+            return None
         row = index.row()
         # Display Role
         if role == Qt.Qt.DisplayRole:
-            return Qt.QVariant(Qt.QString(self.items[row].display))
+            return str(self.items[row].display)
         elif role == Qt.Qt.DecorationRole:
-            return Qt.QVariant(self.items[row].icon)
+            return self.items[row].icon
         elif role == Qt.Qt.TextColorRole:
             if not self.items[row].src:
-                return Qt.QVariant(Qt.QColor('gray'))
-            return Qt.QVariant(Qt.QColor(self.items[row].ok and 'green' or 'red'))
+                return Qt.QColor('gray')
+            return Qt.QColor(self.items[row].ok and 'green' or 'red')
         elif role == SRC_ROLE:
-            return Qt.QVariant(Qt.QString(self.items[row].src))
+            return str(self.items[row].src)
         elif role == Qt.Qt.ToolTipRole:
-            return Qt.QVariant(Qt.QString(self.items[row].src))
+            return str(self.items[row].src)
         if role == Qt.Qt.EditRole:
-            return Qt.QVariant(Qt.QString(self.items[row].src))
-        return Qt.QVariant()
+            return str(self.items[row].src)
+        return None
 
     def flags(self, index):
         '''reimplemented from :class:`Qt.QAbstractListModel`'''
@@ -172,7 +189,6 @@ class TaurusModelModel(Qt.QAbstractListModel):
         if index.isValid() and (0 <= index.row() < self.rowCount()):
             row = index.row()
             item = self.items[row]
-            value = Qt.from_qvariant(value, unicode)
             if role == Qt.Qt.EditRole:
                 item.src = value
             elif role == Qt.Qt.DisplayRole:
@@ -188,7 +204,7 @@ class TaurusModelModel(Qt.QAbstractListModel):
         if parentindex is None:
             parentindex = Qt.QModelIndex()
         if items is None:
-            slice = [TaurusModelItem() for i in xrange(rows)]
+            slice = [TaurusModelItem() for i in range(rows)]
         else:
             slice = list(items)
             # note that the rows parameter is ignored if items is passed
@@ -202,10 +218,11 @@ class TaurusModelModel(Qt.QAbstractListModel):
         '''reimplemented from :class:`Qt.QAbstractListModel`'''
         if parentindex is None:
             parentindex = Qt.QModelIndex()
+        self.beginResetModel()
         self.beginRemoveRows(parentindex, position, position + rows - 1)
         self.items = self.items[:position] + self.items[position + rows:]
         self.endRemoveRows()
-        self.reset()
+        self.endResetModel()
         return True
 
     def clearAll(self):
@@ -230,11 +247,12 @@ class TaurusModelModel(Qt.QAbstractListModel):
         if row == -1 and parent.isValid():
             row = parent.row()
         if data.hasFormat(TAURUS_ATTR_MIME_TYPE):
-            items = [str(data.data(TAURUS_ATTR_MIME_TYPE))]
+            items = [bytes(data.data(TAURUS_ATTR_MIME_TYPE)).decode("utf-8")]
         elif data.hasFormat(TAURUS_MODEL_MIME_TYPE):
-            items = [str(data.data(TAURUS_MODEL_MIME_TYPE))]
+            items = [bytes(data.data(TAURUS_MODEL_MIME_TYPE)).decode("utf-8")]
         elif data.hasFormat(TAURUS_MODEL_LIST_MIME_TYPE):
-            items = str(data.data(TAURUS_MODEL_LIST_MIME_TYPE)).split()
+            items = bytes(
+                data.data(TAURUS_MODEL_LIST_MIME_TYPE)).decode("utf-8").split()
         elif data.hasText():
             items = [str(data.text())]
         else:
@@ -255,7 +273,7 @@ class TaurusModelModel(Qt.QAbstractListModel):
         for e in items:
             if isinstance(e, TaurusModelItem):
                 itemobjs.append(e)
-            elif isinstance(e, basestring):
+            elif isinstance(e, string_types):
                 itemobjs.append(TaurusModelItem(src=e))
             else:  # assuming it is a sequence of arguments that can be passed to the constructor of TaurusModelItem
                 itemobjs.append(TaurusModelItem(*e))
@@ -265,9 +283,8 @@ class TaurusModelModel(Qt.QAbstractListModel):
         '''reimplemented from :class:`Qt.QAbstractListModel`'''
         mimedata = Qt.QAbstractListModel.mimeData(self, indexes)
         if len(indexes) == 1:
-            # mimedata.setData(TAURUS_ATTR_MIME_TYPE,
-            # Qt.from_qvariant(self.data(indexes[0]), str)))
-            txt = Qt.from_qvariant(self.data(indexes[0], role=SRC_ROLE), str)
+            # mimedata.setData(TAURUS_ATTR_MIME_TYPE, self.data(indexes[0]))
+            txt = self.data(indexes[0], role=SRC_ROLE)
             mimedata.setText(txt)
         return mimedata
         # mimedata.setData()
@@ -330,14 +347,13 @@ class TaurusModelList(Qt.QListView):
             idx = selected[0]
         else:
             return
-        value = Qt.from_qvariant(self._model.data(
-            idx, role=Qt.Qt.DisplayRole), str)
-        src = Qt.from_qvariant(self._model.data(idx, role=SRC_ROLE), str)
+        value = self._model.data(idx, role=Qt.Qt.DisplayRole)
+        src = self._model.data(idx, role=SRC_ROLE)
         value, ok = Qt.QInputDialog.getText(
             self, "Display Value", "Display value for %s?" % src, Qt.QLineEdit.Normal, value)
         if not ok:
             return
-        self._model.setData(idx, Qt.QVariant(value), role=Qt.Qt.DisplayRole)
+        self._model.setData(idx, value, role=Qt.Qt.DisplayRole)
 
     def _onSelectionChanged(self, selected, deselected):
         '''updates the status of the actions that depend on the selection'''
@@ -424,7 +440,7 @@ class TaurusModelList(Qt.QListView):
 
         .. seealso:: :meth:`getModelItems`
         '''
-        return [unicode(s.src) for s in self.getModelItems()]
+        return [str(s.src) for s in self.getModelItems()]
 
     @classmethod
     def getQtDesignerPluginInfo(cls):
@@ -438,7 +454,7 @@ class TaurusModelList(Qt.QListView):
 if __name__ == "__main__":
     from taurus.qt.qtgui.application import TaurusApplication
     import sys
-    app = TaurusApplication()
+    app = TaurusApplication(cmd_line_parser=None)
     w = TaurusModelList()
     w.addModels(["item%i" % i for i in range(3)] +
                 [TaurusModelItem(src='src1', display='d1')] + [('src2', 'd2')])
