@@ -34,8 +34,9 @@ from taurus.qt.qtgui.application import TaurusApplication
 
 
 class BaseWidgetTestCase(object):
-
     '''
+    DEPRECATED: use pytest-qt instead of this
+
     A base class for tests that need a widget instance
 
     To use it, simply inherit from BaseWidgetTestCase *and* unittest.TestCase
@@ -59,6 +60,10 @@ class BaseWidgetTestCase(object):
           - The widget must be instantiated
 
         """
+        from taurus.core.util import deprecated
+        deprecated(dep="BaseWidgetTestCase", alt="pytest-qt", rel="4.6.5")
+        raise unittest.SkipTest("*WidgetTestCase is deprecated. Use pytest-qt")
+
         unittest.TestCase.setUp(self)
 
         from taurus.core.util.log import _DEPRECATION_COUNT
@@ -91,8 +96,10 @@ class BaseWidgetTestCase(object):
 
 
 class GenericWidgetTestCase(BaseWidgetTestCase):
+    '''
+    DEPRECATED: use pytest-qt instead of this
 
-    '''a base class for testing common cases of arbitrary Taurus widget classes
+    a base class for testing common cases of arbitrary Taurus widget classes
 
     To use it, simply inherit from GenericWidgetTestCase *and* unittest.TestCase
     and provide the following class members:
@@ -118,6 +125,13 @@ class GenericWidgetTestCase(BaseWidgetTestCase):
             None should be used as a placeholder when a model cannot be created
             for a given modelname.
         """
+        from taurus.core.util import deprecated
+        deprecated(
+            dep="GenericWidgetTestCase",
+            alt="test_set_models and pytest-qt",
+            rel="4.6.5"
+        )
+
         # Make sure the basics are taken care of (QApplication, etc)
         BaseWidgetTestCase.setUp(self)
 
